@@ -10,11 +10,35 @@ Usage::
     client: CodeDeployClient = boto3.client("codedeploy")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_codedeploy.literals import (
+    ApplicationRevisionSortBy,
+    ComputePlatform,
+    DeploymentStatus,
+    DeploymentSuccessfulWaiterName,
+    DeploymentWaitType,
+    FileExistsBehavior,
+    InstanceStatus,
+    InstanceType,
+    LifecycleEventStatus,
+    ListApplicationRevisionsPaginatorName,
+    ListApplicationsPaginatorName,
+    ListDeploymentConfigsPaginatorName,
+    ListDeploymentGroupsPaginatorName,
+    ListDeploymentInstancesPaginatorName,
+    ListDeploymentsPaginatorName,
+    ListDeploymentTargetsPaginatorName,
+    ListGitHubAccountTokenNamesPaginatorName,
+    ListOnPremisesInstancesPaginatorName,
+    ListStateFilterAction,
+    OutdatedInstancesStrategy,
+    RegistrationStatus,
+    SortOrder,
+    TargetFilterName,
+)
 from mypy_boto3_codedeploy.paginator import (
     ListApplicationRevisionsPaginator,
     ListApplicationsPaginator,
@@ -81,12 +105,6 @@ from mypy_boto3_codedeploy.type_defs import (
 )
 from mypy_boto3_codedeploy.waiter import DeploymentSuccessfulWaiter
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("CodeDeployClient",)
 
 
@@ -282,9 +300,7 @@ class CodeDeployClient:
         """
 
     def continue_deployment(
-        self,
-        deploymentId: str = None,
-        deploymentWaitType: Literal["READY_WAIT", "TERMINATION_WAIT"] = None,
+        self, deploymentId: str = None, deploymentWaitType: DeploymentWaitType = None
     ) -> None:
         """
         [Client.continue_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.continue_deployment)
@@ -293,7 +309,7 @@ class CodeDeployClient:
     def create_application(
         self,
         applicationName: str,
-        computePlatform: Literal["Server", "Lambda", "ECS"] = None,
+        computePlatform: ComputePlatform = None,
         tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationOutputTypeDef:
         """
@@ -311,7 +327,7 @@ class CodeDeployClient:
         targetInstances: "TargetInstancesTypeDef" = None,
         autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
         updateOutdatedInstancesOnly: bool = None,
-        fileExistsBehavior: Literal["DISALLOW", "OVERWRITE", "RETAIN"] = None,
+        fileExistsBehavior: FileExistsBehavior = None,
     ) -> CreateDeploymentOutputTypeDef:
         """
         [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment)
@@ -322,7 +338,7 @@ class CodeDeployClient:
         deploymentConfigName: str,
         minimumHealthyHosts: "MinimumHealthyHostsTypeDef" = None,
         trafficRoutingConfig: "TrafficRoutingConfigTypeDef" = None,
-        computePlatform: Literal["Server", "Lambda", "ECS"] = None,
+        computePlatform: ComputePlatform = None,
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
         [Client.create_deployment_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_config)
@@ -340,7 +356,7 @@ class CodeDeployClient:
         triggerConfigurations: List["TriggerConfigTypeDef"] = None,
         alarmConfiguration: "AlarmConfigurationTypeDef" = None,
         autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
-        outdatedInstancesStrategy: Literal["UPDATE", "IGNORE"] = None,
+        outdatedInstancesStrategy: OutdatedInstancesStrategy = None,
         deploymentStyle: "DeploymentStyleTypeDef" = None,
         blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
         loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
@@ -449,11 +465,11 @@ class CodeDeployClient:
     def list_application_revisions(
         self,
         applicationName: str,
-        sortBy: Literal["registerTime", "firstUsedTime", "lastUsedTime"] = None,
-        sortOrder: Literal["ascending", "descending"] = None,
+        sortBy: ApplicationRevisionSortBy = None,
+        sortOrder: SortOrder = None,
         s3Bucket: str = None,
         s3KeyPrefix: str = None,
-        deployed: Literal["include", "exclude", "ignore"] = None,
+        deployed: ListStateFilterAction = None,
         nextToken: str = None,
     ) -> ListApplicationRevisionsOutputTypeDef:
         """
@@ -481,10 +497,8 @@ class CodeDeployClient:
         self,
         deploymentId: str,
         nextToken: str = None,
-        instanceStatusFilter: List[
-            Literal["Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"]
-        ] = None,
-        instanceTypeFilter: List[Literal["Blue", "Green"]] = None,
+        instanceStatusFilter: List[InstanceStatus] = None,
+        instanceTypeFilter: List[InstanceType] = None,
     ) -> ListDeploymentInstancesOutputTypeDef:
         """
         [Client.list_deployment_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_instances)
@@ -494,7 +508,7 @@ class CodeDeployClient:
         self,
         deploymentId: str = None,
         nextToken: str = None,
-        targetFilters: Dict[Literal["TargetStatus", "ServerInstanceLabel"], List[str]] = None,
+        targetFilters: Dict[TargetFilterName, List[str]] = None,
     ) -> ListDeploymentTargetsOutputTypeDef:
         """
         [Client.list_deployment_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.list_deployment_targets)
@@ -505,18 +519,7 @@ class CodeDeployClient:
         applicationName: str = None,
         deploymentGroupName: str = None,
         externalId: str = None,
-        includeOnlyStatuses: List[
-            Literal[
-                "Created",
-                "Queued",
-                "InProgress",
-                "Baking",
-                "Succeeded",
-                "Failed",
-                "Stopped",
-                "Ready",
-            ]
-        ] = None,
+        includeOnlyStatuses: List[DeploymentStatus] = None,
         createTimeRange: TimeRangeTypeDef = None,
         nextToken: str = None,
     ) -> ListDeploymentsOutputTypeDef:
@@ -533,7 +536,7 @@ class CodeDeployClient:
 
     def list_on_premises_instances(
         self,
-        registrationStatus: Literal["Registered", "Deregistered"] = None,
+        registrationStatus: RegistrationStatus = None,
         tagFilters: List["TagFilterTypeDef"] = None,
         nextToken: str = None,
     ) -> ListOnPremisesInstancesOutputTypeDef:
@@ -552,9 +555,7 @@ class CodeDeployClient:
         self,
         deploymentId: str = None,
         lifecycleEventHookExecutionId: str = None,
-        status: Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown"
-        ] = None,
+        status: LifecycleEventStatus = None,
     ) -> PutLifecycleEventHookExecutionStatusOutputTypeDef:
         """
         [Client.put_lifecycle_event_hook_execution_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Client.put_lifecycle_event_hook_execution_status)
@@ -623,7 +624,7 @@ class CodeDeployClient:
         triggerConfigurations: List["TriggerConfigTypeDef"] = None,
         alarmConfiguration: "AlarmConfigurationTypeDef" = None,
         autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
-        outdatedInstancesStrategy: Literal["UPDATE", "IGNORE"] = None,
+        outdatedInstancesStrategy: OutdatedInstancesStrategy = None,
         deploymentStyle: "DeploymentStyleTypeDef" = None,
         blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
         loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
@@ -637,7 +638,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_application_revisions"]
+        self, operation_name: ListApplicationRevisionsPaginatorName
     ) -> ListApplicationRevisionsPaginator:
         """
         [Paginator.ListApplicationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
@@ -645,7 +646,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_applications"]
+        self, operation_name: ListApplicationsPaginatorName
     ) -> ListApplicationsPaginator:
         """
         [Paginator.ListApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
@@ -653,7 +654,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_deployment_configs"]
+        self, operation_name: ListDeploymentConfigsPaginatorName
     ) -> ListDeploymentConfigsPaginator:
         """
         [Paginator.ListDeploymentConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
@@ -661,7 +662,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_deployment_groups"]
+        self, operation_name: ListDeploymentGroupsPaginatorName
     ) -> ListDeploymentGroupsPaginator:
         """
         [Paginator.ListDeploymentGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
@@ -669,7 +670,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_deployment_instances"]
+        self, operation_name: ListDeploymentInstancesPaginatorName
     ) -> ListDeploymentInstancesPaginator:
         """
         [Paginator.ListDeploymentInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
@@ -677,7 +678,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_deployment_targets"]
+        self, operation_name: ListDeploymentTargetsPaginatorName
     ) -> ListDeploymentTargetsPaginator:
         """
         [Paginator.ListDeploymentTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
@@ -685,7 +686,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_deployments"]
+        self, operation_name: ListDeploymentsPaginatorName
     ) -> ListDeploymentsPaginator:
         """
         [Paginator.ListDeployments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
@@ -693,7 +694,7 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_git_hub_account_token_names"]
+        self, operation_name: ListGitHubAccountTokenNamesPaginatorName
     ) -> ListGitHubAccountTokenNamesPaginator:
         """
         [Paginator.ListGitHubAccountTokenNames documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
@@ -701,15 +702,13 @@ class CodeDeployClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_on_premises_instances"]
+        self, operation_name: ListOnPremisesInstancesPaginatorName
     ) -> ListOnPremisesInstancesPaginator:
         """
         [Paginator.ListOnPremisesInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
         """
 
-    def get_waiter(
-        self, waiter_name: Literal["deployment_successful"]
-    ) -> DeploymentSuccessfulWaiter:
+    def get_waiter(self, waiter_name: DeploymentSuccessfulWaiterName) -> DeploymentSuccessfulWaiter:
         """
         [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
         """
