@@ -32,11 +32,20 @@ Usage::
     list_on_premises_instances_paginator: ListOnPremisesInstancesPaginator = client.get_paginator("list_on_premises_instances")
     ```
 """
-import sys
 from typing import Dict, Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_codedeploy.literals import (
+    ApplicationRevisionSortBy,
+    DeploymentStatus,
+    InstanceStatus,
+    InstanceType,
+    ListStateFilterAction,
+    RegistrationStatus,
+    SortOrder,
+    TargetFilterName,
+)
 from mypy_boto3_codedeploy.type_defs import (
     ListApplicationRevisionsOutputTypeDef,
     ListApplicationsOutputTypeDef,
@@ -52,12 +61,6 @@ from mypy_boto3_codedeploy.type_defs import (
     TimeRangeTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListApplicationRevisionsPaginator",
     "ListApplicationsPaginator",
@@ -79,11 +82,11 @@ class ListApplicationRevisionsPaginator(Boto3Paginator):
     def paginate(
         self,
         applicationName: str,
-        sortBy: Literal["registerTime", "firstUsedTime", "lastUsedTime"] = None,
-        sortOrder: Literal["ascending", "descending"] = None,
+        sortBy: ApplicationRevisionSortBy = None,
+        sortOrder: SortOrder = None,
         s3Bucket: str = None,
         s3KeyPrefix: str = None,
-        deployed: Literal["include", "exclude", "ignore"] = None,
+        deployed: ListStateFilterAction = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListApplicationRevisionsOutputTypeDef]:
         """
@@ -138,10 +141,8 @@ class ListDeploymentInstancesPaginator(Boto3Paginator):
     def paginate(
         self,
         deploymentId: str,
-        instanceStatusFilter: List[
-            Literal["Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"]
-        ] = None,
-        instanceTypeFilter: List[Literal["Blue", "Green"]] = None,
+        instanceStatusFilter: List[InstanceStatus] = None,
+        instanceTypeFilter: List[InstanceType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDeploymentInstancesOutputTypeDef]:
         """
@@ -157,7 +158,7 @@ class ListDeploymentTargetsPaginator(Boto3Paginator):
     def paginate(
         self,
         deploymentId: str = None,
-        targetFilters: Dict[Literal["TargetStatus", "ServerInstanceLabel"], List[str]] = None,
+        targetFilters: Dict[TargetFilterName, List[str]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDeploymentTargetsOutputTypeDef]:
         """
@@ -175,18 +176,7 @@ class ListDeploymentsPaginator(Boto3Paginator):
         applicationName: str = None,
         deploymentGroupName: str = None,
         externalId: str = None,
-        includeOnlyStatuses: List[
-            Literal[
-                "Created",
-                "Queued",
-                "InProgress",
-                "Baking",
-                "Succeeded",
-                "Failed",
-                "Stopped",
-                "Ready",
-            ]
-        ] = None,
+        includeOnlyStatuses: List[DeploymentStatus] = None,
         createTimeRange: TimeRangeTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListDeploymentsOutputTypeDef]:
@@ -215,7 +205,7 @@ class ListOnPremisesInstancesPaginator(Boto3Paginator):
 
     def paginate(
         self,
-        registrationStatus: Literal["Registered", "Deregistered"] = None,
+        registrationStatus: RegistrationStatus = None,
         tagFilters: List["TagFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListOnPremisesInstancesOutputTypeDef]:
